@@ -598,7 +598,7 @@ class DescribeTemplatesRequest(AbstractModel):
         :type Agent: :class:`tencentcloud.essbasic.v20210526.models.Agent`
         :param Operator: 操作者的信息
         :type Operator: :class:`tencentcloud.essbasic.v20210526.models.UserInfo`
-        :param TemplateId: 模版唯一标识
+        :param TemplateId: 模板唯一标识
         :type TemplateId: str
         """
         self.Agent = None
@@ -841,10 +841,10 @@ class FlowApproverInfo(AbstractModel):
         r"""
         :param Name: 签署人姓名
         :type Name: str
-        :param Mobile: 签署人手机号，脱敏显示
-        :type Mobile: str
         :param IdCardNumber: 经办人身份证号
         :type IdCardNumber: str
+        :param Mobile: 签署人手机号，脱敏显示
+        :type Mobile: str
         :param JumpUrl: 签署完前端跳转的url，暂未使用
         :type JumpUrl: str
         :param Deadline: 签署截止时间
@@ -857,28 +857,44 @@ class FlowApproverInfo(AbstractModel):
         :type OpenId: str
         :param PreReadTime: 合同的强制预览时间：3~300s，未指定则按合同页数计算
         :type PreReadTime: int
+        :param ComponentLimitType: 个人签署方指定签署控件类型，目前仅支持：OCR_ESIGN
+        :type ComponentLimitType: list of str
+        :param RecipientId: 流程签署人在模板中对应的签署人Id；在非单方签署、以及非B2C签署的场景下必传，用于指定当前签署方在流程中的位置；
+        :type RecipientId: str
+        :param OrganizationOpenId: 同一渠道下其他合作企业OpenId，签署人为非发起方企业员工场景下必传；
+        :type OrganizationOpenId: str
+        :param OrganizationName: 同一渠道下其他合作企业OpenId，B2B场景下必传；
+        :type OrganizationName: str
         """
         self.Name = None
-        self.Mobile = None
         self.IdCardNumber = None
+        self.Mobile = None
         self.JumpUrl = None
         self.Deadline = None
         self.CallbackUrl = None
         self.ApproverType = None
         self.OpenId = None
         self.PreReadTime = None
+        self.ComponentLimitType = None
+        self.RecipientId = None
+        self.OrganizationOpenId = None
+        self.OrganizationName = None
 
 
     def _deserialize(self, params):
         self.Name = params.get("Name")
-        self.Mobile = params.get("Mobile")
         self.IdCardNumber = params.get("IdCardNumber")
+        self.Mobile = params.get("Mobile")
         self.JumpUrl = params.get("JumpUrl")
         self.Deadline = params.get("Deadline")
         self.CallbackUrl = params.get("CallbackUrl")
         self.ApproverType = params.get("ApproverType")
         self.OpenId = params.get("OpenId")
         self.PreReadTime = params.get("PreReadTime")
+        self.ComponentLimitType = params.get("ComponentLimitType")
+        self.RecipientId = params.get("RecipientId")
+        self.OrganizationOpenId = params.get("OrganizationOpenId")
+        self.OrganizationName = params.get("OrganizationName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -978,7 +994,7 @@ class FlowInfo(AbstractModel):
         :type FlowDescription: str
         :param CustomerData: 渠道的业务信息，限制1024字符
         :type CustomerData: str
-        :param CcInfos: 被抄送人的信息列表
+        :param CcInfos: 被抄送人的信息列表，抄送功能暂不开放
         :type CcInfos: list of CcInfo
         """
         self.FlowName = None
